import request from "@/utils/request"

/** 休药期标准 — 分页列表 */
export function listWithdrawalPeriodStandard(query) {
  return request({
    url: "/withdrawalPeriod/standard/list",
    method: "get",
    params: query
  })
}

/** 详情 */
export function getWithdrawalPeriodStandard(id) {
  return request({
    url: "/withdrawalPeriod/standard/" + id,
    method: "get"
  })
}

/** 新增 */
export function addWithdrawalPeriodStandard(data) {
  return request({
    url: "/withdrawalPeriod/standard",
    method: "post",
    data
  })
}

/** 修改 */
export function updateWithdrawalPeriodStandard(data) {
  return request({
    url: "/withdrawalPeriod/standard",
    method: "put",
    data
  })
}

/** 删除 */
export function delWithdrawalPeriodStandard(ids) {
  return request({
    url: "/withdrawalPeriod/standard/" + ids,
    method: "delete"
  })
}

/** 同步知识库 */
export function syncKbWithdrawalPeriodStandard(id) {
  return request({
    url: "/withdrawalPeriod/standard/syncKb/" + id,
    method: "post"
  })
}

/** 移出知识库 */
export function removeKbWithdrawalPeriodStandard(id) {
  return request({
    url: "/withdrawalPeriod/standard/removeKb/" + id,
    method: "post"
  })
}
